clear all
rng(100,'twister')
uqlab

% AIM : report what seems to be a bug. 
% Description of the problem : A_PCK_MCS does not work if the first input is
% a constant (AKMCS works), and it creates further problems if the second
% input is a constant


% model : comes from https://www.uqlab.com/reliability-2d-hat-function
ModelOpts.mString = '20 - (X(:,1)-X(:,2)).^2 - 8*(X(:,1)+X(:,2)-4).^3';
ModelOpts.isVectorized = true;

myModel = uq_createModel(ModelOpts);


%% Input 1 : (Gaussian, Gaussian) 
Input1.Marginals(1).Name = 'X1';
Input1.Marginals(1).Type = 'Gaussian';
Input1.Marginals(1).Parameters = [0.25 1];

Input1.Marginals(2).Name = 'X2';
Input1.Marginals(2).Type = 'Gaussian';
Input1.Marginals(2).Parameters = [0.25 1];

myInput1 = uq_createInput(Input1);

%% First A_PCK_MCS with 2 Gaussian inputs : works well, as in the example
APCKMCS1.Type = 'Reliability';
APCKMCS1.Method = 'AKMCS';
APCKMCS1.AKMCS.MetaModel = 'PCK';
myAPCKMCSAnalysis1 = uq_createAnalysis(APCKMCS1);





%% Input 2 : (Constant, Gaussian)
Input2.Marginals(1).Name = 'X1';
Input2.Marginals(1).Type = 'Constant';
Input2.Marginals(1).Parameters = 0.25;

Input2.Marginals(2).Name = 'X2';
Input2.Marginals(2).Type = 'Gaussian';
Input2.Marginals(2).Parameters = [0.25 1];

myInput2 = uq_createInput(Input2);

%% Second A_PCK_MCS with the first input constant : an error is returned 
APCKMCS2.Type = 'Reliability';
APCKMCS2.Method = 'AKMCS';
APCKMCS2.AKMCS.MetaModel = 'PCK';
myAPCKMCSAnalysis2 = uq_createAnalysis(APCKMCS2);

%% AKMCS (with Kriging and not PCK) works well :
AKMCS2.Type = 'Reliability';
AKMCS2.Method = 'AKMCS';
%AKMCS2.AKMCS.MetaModel = 'PCK';
myAKMCSAnalysis2 = uq_createAnalysis(AKMCS2);





%% Input 3 : (Gaussian, Constant)
Input3.Marginals(1).Name = 'X1';
Input3.Marginals(1).Type = 'Gaussian';
Input3.Marginals(1).Parameters = [0.25 1];

Input3.Marginals(2).Name = 'X2';
Input3.Marginals(2).Type = 'Constant';
Input3.Marginals(2).Parameters = 0.25 ; 

myInput3 = uq_createInput(Input3);

%% Third A_PCK_MCS with the second input constant : works but just the first time 
APCKMCS3.Type = 'Reliability';
APCKMCS3.Method = 'AKMCS';
APCKMCS3.AKMCS.MetaModel = 'PCK';
myAPCKMCSAnalysis3 = uq_createAnalysis(APCKMCS3);

%% AKMCS (with Kriging and not PCK) works well alone, but does not work if run AFTER the APCK-MCS 
AKMCS3.Type = 'Reliability';
AKMCS3.Method = 'AKMCS';
%AKMC3.AKMCS.MetaModel = 'PCK';
myAKMCSAnalysis3 = uq_createAnalysis(AKMCS3);